@@ -1,6 +1,7 @@
 import io
 from collections import OrderedDict
 from pathlib import Path
+from typing import Union
 
 import yaml
 
@@ -39,13 +40,15 @@ class PreSetAttributesBuilder(Builder):
 class Service(OrderedDict, yaml.YAMLObject):
     yaml_tag = "!Service"
 
-    def __init__(self, name: str, description: str, provider: Provider, config=None, /, **kwds):
+    def __init__(
+        self, name: str, description: str, provider: Provider, config=None, custom: Union[dict, None] = None, /, **kwds
+    ):
         super().__init__(**kwds)
 
         self.service = Identifier(name)
         self.package = Package(["!./**/**", f"{self.service.snake}/**"])
         self.variablesResolutionMode = 20210326
-        self.custom = YamlOrderedDict(vars="${file(./variables.yml):${sls:stage}}")
+        self.custom = YamlOrderedDict(vars="${file(./variables.yml):${sls:stage}}", **(custom or {}))
 
         self.config = config if config else Configuration()
 
