@@ -3,4 +3,4 @@ from serverless.service.types import SmartString
 
 class Configuration:
     def __init__(self, domain=None):
-        self.domain = SmartString(domain)
+        self.domain = SmartString(domain) if domain else None
